@@ -1,8 +1,12 @@
 import os
+import shutil
+from glob import glob
 from pathlib import Path
 
 import joblib
 import polars as pl
+from phylogenie import Tree, load_nexus
+from tqdm import tqdm
 
 from bella_companion.utils import read_weights_dir, summarize_logs_dir
 
@@ -28,3 +32,10 @@ def summarize_logs():
     os.makedirs(summaries_dir, exist_ok=True)
     summaries.write_csv(summaries_dir / "MLP.csv")
     joblib.dump(weights, summaries_dir / "MLP.weights.pkl")
+
+    trees: list[Tree] = []
+    for tree_file in tqdm(glob(str(logs_dir / "*.trees")), "Summarizing trees"):
+        trees.extend(list(load_nexus(tree_file).values())[:-10])
+    joblib.dump(trees, summaries_dir / "trees.pkl")
+
+    shutil.copy(logs_dir / "0.trees", summaries_dir / "sample-tree.nexus")
